@@ -36,6 +36,8 @@ const NotificationDirection = {
     RECEIVED: 'chat-received'
 };
 
+const N_ = function(s) { return s; };
+
 function makeMessageFromTpMessage(tpMessage, direction) {
     let [text, flags] = tpMessage.to_text();
 
@@ -950,70 +952,70 @@ const ChatNotification = new Lang.Class({
             // Show only the time if date is on today
             if(daysAgo < 1){
                 /* Translators: Time in 24h format */
-                format = _("%H\u2236%M");
+                format = N_("%H\u2236%M");
             }
             // Show the word "Yesterday" and time if date is on yesterday
             else if(daysAgo <2){
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 24h format. i.e. "Yesterday, 14:30" */
                 // xgettext:no-c-format
-                format = _("Yesterday, %H\u2236%M");
+                format = N_("Yesterday, %H\u2236%M");
             }
             // Show a week day and time if date is in the last week
             else if (daysAgo < 7) {
                 /* Translators: this is the week day name followed by a time
                  string in 24h format. i.e. "Monday, 14:30" */
                 // xgettext:no-c-format
-                format = _("%A, %H\u2236%M");
+                format = N_("%A, %H\u2236%M");
 
             } else if (date.getYear() == now.getYear()) {
                 /* Translators: this is the month name and day number
                  followed by a time string in 24h format.
                  i.e. "May 25, 14:30" */
                 // xgettext:no-c-format
-                format = _("%B %d, %H\u2236%M");
+                format = N_("%B %d, %H\u2236%M");
             } else {
                 /* Translators: this is the month name, day number, year
                  number followed by a time string in 24h format.
                  i.e. "May 25 2012, 14:30" */
                 // xgettext:no-c-format
-                format = _("%B %d %Y, %H\u2236%M");
+                format = N_("%B %d %Y, %H\u2236%M");
             }
         } else {
             // Show only the time if date is on today
             if(daysAgo < 1){
                 /* Translators: Time in 24h format */
-                format = _("%l\u2236%M %p");
+                format = N_("%l\u2236%M %p");
             }
             // Show the word "Yesterday" and time if date is on yesterday
             else if(daysAgo <2){
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 12h format. i.e. "Yesterday, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("Yesterday, %l\u2236%M %p");
+                format = N_("Yesterday, %l\u2236%M %p");
             }
             // Show a week day and time if date is in the last week
             else if (daysAgo < 7) {
                 /* Translators: this is the week day name followed by a time
                  string in 12h format. i.e. "Monday, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("%A, %l\u2236%M %p");
+                format = N_("%A, %l\u2236%M %p");
 
             } else if (date.getYear() == now.getYear()) {
                 /* Translators: this is the month name and day number
                  followed by a time string in 12h format.
                  i.e. "May 25, 2:30 pm" */
                 // xgettext:no-c-format
-                format = _("%B %d, %l\u2236%M %p");
+                format = N_("%B %d, %l\u2236%M %p");
             } else {
                 /* Translators: this is the month name, day number, year
                  number followed by a time string in 12h format.
                  i.e. "May 25 2012, 2:30 pm"*/
                 // xgettext:no-c-format
-                format = _("%B %d %Y, %l\u2236%M %p");
+                format = N_("%B %d %Y, %l\u2236%M %p");
             }
         }
-        return date.toLocaleFormat(format);
+        return date.toLocaleFormat(Shell.util_translate_time_string(format));
     },
 
     appendTimestamp: function() {
@@ -1264,9 +1266,8 @@ const SubscriptionRequestNotification = new Lang.Class({
         let file = contact.get_avatar_file();
 
         if (file) {
-            let uri = file.get_uri();
             let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
-            iconBox.child = textureCache.load_uri_async(uri, iconBox._size, iconBox._size, scaleFactor);
+            iconBox.child = textureCache.load_file_async(file, iconBox._size, iconBox._size, scaleFactor);
         }
         else {
             iconBox.child = new St.Icon({ icon_name: 'avatar-default',
