@@ -509,7 +509,7 @@ const Overview = new Lang.Class({
             if (shouldBeModal) {
                 if (!this._modal) {
                     if (Main.pushModal(this._overview,
-                                       { keybindingMode: Shell.KeyBindingMode.OVERVIEW })) {
+                                       { actionMode: Shell.ActionMode.OVERVIEW })) {
                         this._modal = true;
                     } else {
                         this.hide();
@@ -605,9 +605,9 @@ const Overview = new Lang.Class({
                 return;
         }
 
-        this._animateNotVisible();
-
         this._shown = false;
+
+        this._animateNotVisible();
         this._syncGrab();
     },
 
