@@ -580,6 +580,35 @@ const AppSwitchAction = new Lang.Class({
 });
 Signals.addSignalMethods(AppSwitchAction.prototype);
 
+const ResizePopup = new Lang.Class({
+    Name: 'ResizePopup',
+
+    _init: function() {
+        this._widget = new St.Widget({ layout_manager: new Clutter.BinLayout() });
+        this._label = new St.Label({ style_class: 'resize-popup',
+                                     x_align: Clutter.ActorAlign.CENTER,
+                                     y_align: Clutter.ActorAlign.CENTER,
+                                     x_expand: true, y_expand: true });
+        this._widget.add_child(this._label);
+        Main.uiGroup.add_actor(this._widget);
+    },
+
+    set: function(rect, displayW, displayH) {
+        /* Translators: This represents the size of a window. The first number is
+         * the width of the window and the second is the height. */
+        let text = _("%d x %d").format(displayW, displayH);
+        this._label.set_text(text);
+
+        this._widget.set_position(rect.x, rect.y);
+        this._widget.set_size(rect.width, rect.height);
+    },
+
+    destroy: function() {
+        this._widget.destroy();
+        this._widget = null;
+    },
+});
+
 const WindowManager = new Lang.Class({
     Name: 'WindowManager',
 
@@ -792,6 +821,8 @@ const WindowManager = new Lang.Class({
                            Shell.ActionMode.TOPBAR_POPUP,
                            Lang.bind(this, this._toggleAppMenu));
 
+        global.display.connect('show-resize-popup', Lang.bind(this, this._showResizePopup));
+
         Main.overview.connect('showing', Lang.bind(this, function() {
             for (let i = 0; i < this._dimmedWindows.length; i++)
                 this._undimWindow(this._dimmedWindows[i]);
@@ -857,6 +888,44 @@ const WindowManager = new Lang.Class({
         Main.activateWindow(nextWindow);
     },
 
+    insertWorkspace: function(pos) {
+        if (!Meta.prefs_get_dynamic_workspaces())
+            return;
+
+        let windows = global.get_window_actors().map(function(winActor) {
+            return winActor.meta_window;
+        });
+
+        // To create a new workspace, we slide all the windows on workspaces
+        // below us to the next workspace, leaving a blank workspace for us
+        // to recycle.
+        windows.forEach(function(window) {
+            // If the window is attached to an ancestor, we don't need/want
+            // to move it
+            if (window.get_transient_for() != null)
+                return;
+            // Same for OR windows
+            if (window.is_override_redirect())
+                return;
+            // Windows on workspaces below pos don't need moving
+            let index = window.get_workspace().index();
+            if (index < pos)
+                return;
+            window.change_workspace_by_index(index + 1, true);
+        });
+
+        // If the new workspace was inserted before the active workspace,
+        // activate the workspace to which its windows went
+        let activeIndex = global.screen.get_active_workspace_index();
+        if (activeIndex >= pos) {
+            let newWs = global.screen.get_workspace_by_index(activeIndex + 1);
+            this._blockAnimations = true;
+            newWs.activate(global.get_current_time());
+            this._blockAnimations = false;
+        }
+    },
+
+
     keepWorkspaceAlive: function(workspace, duration) {
         if (!this._workspaceTracker)
             return;
@@ -886,7 +955,7 @@ const WindowManager = new Lang.Class({
     },
 
     _shouldAnimate: function() {
-        return !Main.overview.visible;
+        return !(Main.overview.visible || this._blockAnimations);
     },
 
     _shouldAnimateActor: function(actor, types) {
@@ -1077,10 +1146,8 @@ const WindowManager = new Lang.Class({
             return;
         }
 
-        if (actor.meta_window.is_attached_dialog()) {
-            /* Scale the window from the center of the parent */
+        if (actor.meta_window.is_attached_dialog())
             this._checkDimming(actor.get_meta_window().get_transient_for());
-        }
 
         switch (actor._windowType) {
         case Meta.WindowType.NORMAL:
@@ -1458,6 +1525,11 @@ const WindowManager = new Lang.Class({
             direction = Meta.MotionDirection.DOWN;
             newWs = screen.get_workspace_by_index(screen.n_workspaces - 1);
         } else if (isNaN(target)) {
+            // Prepend a new workspace dynamically
+            if (screen.get_active_workspace_index() == 0 &&
+                action == 'move' && target == 'up')
+                this.insertWorkspace(0);
+
             direction = Meta.MotionDirection[target.toUpperCase()];
             newWs = screen.get_active_workspace().get_neighbor(direction);
         } else if (target > 0) {
@@ -1522,4 +1594,18 @@ const WindowManager = new Lang.Class({
         let dialog = new DisplayChangeDialog(this._shellwm);
         dialog.open();
     },
+
+    _showResizePopup: function(display, show, rect, displayW, displayH) {
+        if (show) {
+            if (!this._resizePopup)
+                this._resizePopup = new ResizePopup();
+
+            this._resizePopup.set(rect, displayW, displayH);
+        } else {
+            if (this._resizePopup) {
+                this._resizePopup.destroy();
+                this._resizePopup = null;
+            }
+        }
+    },
 });
