@@ -156,7 +156,7 @@ G_DEFINE_TYPE(ShellRecorder, shell_recorder, G_TYPE_OBJECT);
  * (Theora does have some support for frames at non-uniform times, but
  * things seem to break down if there are large gaps.)
  */
-#define DEFAULT_PIPELINE "vp8enc min_quantizer=13 max_quantizer=13 cpu-used=5 deadline=1000000 threads=%T ! queue ! webmmux"
+#define DEFAULT_PIPELINE "vp9enc min_quantizer=13 max_quantizer=13 cpu-used=5 deadline=1000000 threads=%T ! queue ! webmmux"
 
 /* If we can find the amount of memory on the machine, we use half
  * of that for memory_target, otherwise, we use this value, in kB.
@@ -437,14 +437,14 @@ recorder_record_frame (ShellRecorder *recorder)
 
   size = recorder->area.width * recorder->area.height * 4;
 
-  data = g_malloc (recorder->area.width * 4 * recorder->area.height);
-  cogl_read_pixels (recorder->area.x,
-                    recorder->area.y,
-                    recorder->area.width,
-                    recorder->area.height,
-                    COGL_READ_PIXELS_COLOR_BUFFER,
-                    CLUTTER_CAIRO_FORMAT_ARGB32,
-                    data);
+  data = g_malloc (size);
+  cogl_framebuffer_read_pixels (cogl_get_draw_framebuffer (),
+                                recorder->area.x,
+                                recorder->area.y,
+                                recorder->area.width,
+                                recorder->area.height,
+                                CLUTTER_CAIRO_FORMAT_ARGB32,
+                                data);
 
   buffer = gst_buffer_new();
   gst_buffer_insert_memory (buffer, -1,
@@ -1261,7 +1261,7 @@ recorder_pipeline_closed (RecorderPipeline *pipeline)
 
 /*
  * Replaces '%T' in the passed pipeline with the thread count,
- * the maximum possible value is 64 (limit of what vp8enc supports)
+ * the maximum possible value is 64 (limit of what vp9enc supports)
  *
  * It is assumes that %T occurs only once.
  */
@@ -1291,7 +1291,7 @@ substitute_thread_count (const char *pipeline)
   g_string_append_printf (result, "%d", n_threads);
   g_string_append (result, tmp + 2);
 
-  return g_string_free (result, FALSE);;
+  return g_string_free (result, FALSE);
 }
 
 static gboolean
@@ -1303,7 +1303,7 @@ recorder_open_pipeline (ShellRecorder *recorder)
   GError *error = NULL;
   GstBus *bus;
 
-  pipeline = g_new0(RecorderPipeline, 1);
+  pipeline = g_new0 (RecorderPipeline, 1);
   pipeline->recorder = g_object_ref (recorder);
   pipeline->outfile = - 1;
 
@@ -1459,7 +1459,7 @@ shell_recorder_set_draw_cursor (ShellRecorder *recorder,
  * might be used to send the output to an icecast server
  * via shout2send or similar.
  *
- * The default value is 'vp8enc min_quantizer=13 max_quantizer=13 cpu-used=5 deadline=1000000 threads=%T ! queue ! webmmux'
+ * The default value is 'vp9enc min_quantizer=13 max_quantizer=13 cpu-used=5 deadline=1000000 threads=%T ! queue ! webmmux'
  */
 void
 shell_recorder_set_pipeline (ShellRecorder *recorder,
